@@ -5,12 +5,18 @@ use core::fmt::{self, Debug, Display, Formatter, Write};
 use core::hash::{Hash, Hasher};
 use core::iter::FromIterator;
 use core::ops::{
-  Add, Deref, DerefMut, Index, IndexMut, Range, RangeFrom, RangeFull, RangeInclusive, RangeTo,
-  RangeToInclusive,
+  Add, AddAssign, Deref, DerefMut, Index, IndexMut, Range, RangeFrom, RangeFull, RangeInclusive,
+  RangeTo, RangeToInclusive,
 };
 use core::str::{self, FromStr};
 
-impl<'a, const N: usize> Add<&'a str> for StaticString<N> {
+#[cfg(feature = "std")]
+use crate::StaticVec;
+
+#[cfg(feature = "std")]
+use alloc::string::String;
+
+impl<const N: usize> Add<&str> for StaticString<N> {
   type Output = Self;
 
   #[inline(always)]
@@ -20,6 +26,13 @@ impl<'a, const N: usize> Add<&'a str> for StaticString<N> {
   }
 }
 
+impl<const N: usize> AddAssign<&str> for StaticString<N> {
+  #[inline(always)]
+  fn add_assign(&mut self, other: &str) {
+    self.push_str_truncating(other);
+  }
+}
+
 impl<const N: usize> AsMut<str> for StaticString<N> {
   #[inline(always)]
   fn as_mut(&mut self) -> &mut str {
@@ -77,14 +90,14 @@ impl<const N: usize> Deref for StaticString<N> {
 
   #[inline(always)]
   fn deref(&self) -> &Self::Target {
-    self.as_ref()
+    self.as_str()
   }
 }
 
 impl<const N: usize> DerefMut for StaticString<N> {
   #[inline(always)]
   fn deref_mut(&mut self) -> &mut Self::Target {
-    self.as_mut()
+    self.as_mut_str()
   }
 }
 
@@ -125,6 +138,16 @@ impl<'a, const N: usize> From<&'a str> for StaticString<N> {
   }
 }
 
+#[cfg(feature = "std")]
+impl<const N: usize> From<String> for StaticString<N> {
+  #[inline(always)]
+  fn from(string: String) -> Self {
+    Self {
+      vec: StaticVec::from_iter(string.into_bytes().iter()),
+    }
+  }
+}
+
 impl<const N: usize> FromIterator<char> for StaticString<N> {
   #[inline(always)]
   fn from_iter<I: IntoIterator<Item = char>>(iter: I) -> Self {
@@ -132,6 +155,13 @@ impl<const N: usize> FromIterator<char> for StaticString<N> {
   }
 }
 
+impl<'a, const N: usize> FromIterator<&'a char> for StaticString<N> {
+  #[inline(always)]
+  fn from_iter<I: IntoIterator<Item = &'a char>>(iter: I) -> Self {
+    Self::from_chars(iter.into_iter().copied())
+  }
+}
+
 impl<'a, const N: usize> FromIterator<&'a str> for StaticString<N> {
   #[inline(always)]
   fn from_iter<I: IntoIterator<Item = &'a str>>(iter: I) -> Self {
@@ -160,17 +190,14 @@ impl<const N: usize> Index<Range<usize>> for StaticString<N> {
 
   #[inline(always)]
   fn index(&self, index: Range<usize>) -> &Self::Output {
-    let (start, end) = (index.start as usize, index.end as usize);
-    self.as_str().index(Range { start, end })
+    self.as_str().index(index)
   }
 }
 
 impl<const N: usize> IndexMut<Range<usize>> for StaticString<N> {
   #[inline(always)]
   fn index_mut(&mut self, index: Range<usize>) -> &mut str {
-    let (start, end) = (index.start as usize, index.end as usize);
-    let range = Range { start, end };
-    self.as_mut_str().index_mut(range)
+    self.as_mut_str().index_mut(index)
   }
 }
 
@@ -179,16 +206,14 @@ impl<const N: usize> Index<RangeFrom<usize>> for StaticString<N> {
 
   #[inline(always)]
   fn index(&self, index: RangeFrom<usize>) -> &Self::Output {
-    let start = index.start as usize;
-    self.as_str().index(RangeFrom { start })
+    self.as_str().index(index)
   }
 }
 
 impl<const N: usize> IndexMut<RangeFrom<usize>> for StaticString<N> {
   #[inline(always)]
   fn index_mut(&mut self, index: RangeFrom<usize>) -> &mut str {
-    let start = index.start as usize;
-    self.as_mut_str().index_mut(RangeFrom { start })
+    self.as_mut_str().index_mut(index)
   }
 }
 
@@ -196,15 +221,15 @@ impl<const N: usize> Index<RangeFull> for StaticString<N> {
   type Output = str;
 
   #[inline(always)]
-  fn index(&self, index: RangeFull) -> &Self::Output {
-    self.as_str().index(index)
+  fn index(&self, _index: RangeFull) -> &Self::Output {
+    self.as_str()
   }
 }
 
 impl<const N: usize> IndexMut<RangeFull> for StaticString<N> {
   #[inline(always)]
-  fn index_mut(&mut self, index: RangeFull) -> &mut str {
-    self.as_mut_str().index_mut(index)
+  fn index_mut(&mut self, _index: RangeFull) -> &mut str {
+    self.as_mut_str()
   }
 }
 
@@ -213,18 +238,14 @@ impl<const N: usize> Index<RangeInclusive<usize>> for StaticString<N> {
 
   #[inline(always)]
   fn index(&self, index: RangeInclusive<usize>) -> &Self::Output {
-    let (start, end) = (*index.start(), *index.end());
-    let range = RangeInclusive::new(start, end);
-    self.as_str().index(range)
+    self.as_str().index(index)
   }
 }
 
 impl<const N: usize> IndexMut<RangeInclusive<usize>> for StaticString<N> {
   #[inline(always)]
   fn index_mut(&mut self, index: RangeInclusive<usize>) -> &mut str {
-    let (start, end) = (*index.start() as usize, *index.end() as usize);
-    let range = RangeInclusive::new(start, end);
-    self.as_mut_str().index_mut(range)
+    self.as_mut_str().index_mut(index)
   }
 }
 
@@ -233,16 +254,14 @@ impl<const N: usize> Index<RangeTo<usize>> for StaticString<N> {
 
   #[inline(always)]
   fn index(&self, index: RangeTo<usize>) -> &Self::Output {
-    let end = index.end as usize;
-    self.as_str().index(RangeTo { end })
+    self.as_str().index(index)
   }
 }
 
 impl<const N: usize> IndexMut<RangeTo<usize>> for StaticString<N> {
   #[inline(always)]
   fn index_mut(&mut self, index: RangeTo<usize>) -> &mut str {
-    let end = index.end as usize;
-    self.as_mut_str().index_mut(RangeTo { end })
+    self.as_mut_str().index_mut(index)
   }
 }
 
@@ -251,17 +270,14 @@ impl<const N: usize> Index<RangeToInclusive<usize>> for StaticString<N> {
 
   #[inline(always)]
   fn index(&self, index: RangeToInclusive<usize>) -> &Self::Output {
-    let end = index.end as usize;
-    self.as_str().index(RangeToInclusive { end })
+    self.as_str().index(index)
   }
 }
 
 impl<const N: usize> IndexMut<RangeToInclusive<usize>> for StaticString<N> {
   #[inline(always)]
   fn index_mut(&mut self, index: RangeToInclusive<usize>) -> &mut str {
-    let end = index.end as usize;
-    let range = RangeToInclusive { end };
-    self.as_mut_str().index_mut(range)
+    self.as_mut_str().index_mut(index)
   }
 }
 
@@ -293,6 +309,14 @@ impl<const N: usize> PartialEq<&str> for StaticString<N> {
   }
 }
 
+#[cfg(feature = "std")]
+impl<const N: usize> PartialEq<String> for StaticString<N> {
+  #[inline(always)]
+  fn eq(&self, other: &String) -> bool {
+    self.as_str().eq(other.as_str())
+  }
+}
+
 impl<const N: usize> PartialOrd for StaticString<N> {
   #[inline(always)]
   fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
@@ -314,6 +338,14 @@ impl<const N: usize> PartialOrd<&str> for StaticString<N> {
   }
 }
 
+#[cfg(feature = "std")]
+impl<const N: usize> PartialOrd<String> for StaticString<N> {
+  #[inline(always)]
+  fn partial_cmp(&self, other: &String) -> Option<Ordering> {
+    Some(self.as_str().cmp(other.as_str()))
+  }
+}
+
 impl<const N: usize> Write for StaticString<N> {
   #[inline(always)]
   fn write_str(&mut self, s: &str) -> fmt::Result {
